@@ -34,32 +34,47 @@ typedef struct _TerminalColorScheme TerminalColorScheme;
 struct _TerminalColorScheme
 {
 	const char *name;
-	const GdkColor foreground;
-	const GdkColor background;
+	const GdkRGBA foreground;
+	const GdkRGBA background;
 };
 
 static const TerminalColorScheme color_schemes[] =
 {
 	{
 		N_("Black on light yellow"),
-		{ 0, 0x0000, 0x0000, 0x0000 }, { 0, 0xFFFF, 0xFFFF, 0xDDDD }
+		{ 0, 0, 0, 1 },
+		{ 1, 1, 0.866667, 1 }
 	},
 	{
 		N_("Black on white"),
-		{ 0, 0x0000, 0x0000, 0x0000 }, { 0, 0xFFFF, 0xFFFF, 0xFFFF }
+		{ 0, 0, 0, 1 },
+		{ 1, 1, 1, 1 }
 	},
 	{
 		N_("Gray on black"),
-		{ 0, 0xAAAA, 0xAAAA, 0xAAAA }, { 0, 0x0000, 0x0000, 0x0000 }
+		{ 0.666667, 0.666667, 0.666667, 1 },
+		{ 0, 0, 0, 1 }
 	},
 	{
 		N_("Green on black"),
-		{ 0, 0x0000, 0xFFFF, 0x0000 }, { 0, 0x0000, 0x0000, 0x0000 }
+		{ 0, 1, 0, 1 },
+		{ 0, 0, 0, 1 }
 	},
 	{
 		N_("White on black"),
-		{ 0, 0xFFFF, 0xFFFF, 0xFFFF }, { 0, 0x0000, 0x0000, 0x0000 }
-	}
+		{ 1, 1, 1, 1 },
+		{ 0, 0, 0, 1 }
+	},
+	/* Translators: "Solarized" is the name of a colour scheme, "light" can be translated */
+	{ N_("Solarized light"),
+		{ 0.396078, 0.482352, 0.513725, 1 },
+		{ 0.992156, 0.964705, 0.890196, 1 }
+	},
+	/* Translators: "Solarized" is the name of a colour scheme, "dark" can be translated */
+	{ N_("Solarized dark"),
+		{ 0.513725, 0.580392, 0.588235, 1 },
+		{ 0,        0.168627, 0.211764, 1 }
+	},
 };
 
 static void profile_forgotten_cb (TerminalProfile           *profile,
@@ -141,10 +156,9 @@ profile_notify_sensitivity_cb (TerminalProfile *profile,
 		               !terminal_profile_property_locked (profile, TERMINAL_PROFILE_CUSTOM_COMMAND));
 	}
 
-#if VTE_CHECK_VERSION (0, 38, 0)
-	gtk_widget_hide (profile_editor_get_widget (editor, "background-image"));
 	gtk_widget_hide (profile_editor_get_widget (editor, "darken-background-transparent-or-image-scale-label"));
 	gtk_widget_show (profile_editor_get_widget (editor, "darken-background-transparent-scale-label"));
+	gtk_widget_hide (profile_editor_get_widget (editor, "scroll-background-checkbutton"));
 	if (!prop_name || prop_name == I_(TERMINAL_PROFILE_BACKGROUND_TYPE))
 	{
 		gboolean bg_type_locked = terminal_profile_property_locked (profile, TERMINAL_PROFILE_BACKGROUND_TYPE);
@@ -161,35 +175,6 @@ profile_notify_sensitivity_cb (TerminalProfile *profile,
 			SET_SENSITIVE ("darken-background-vbox", FALSE);
 		}
 	}
-#else
-	if (!prop_name || prop_name == I_(TERMINAL_PROFILE_BACKGROUND_TYPE))
-	{
-		gboolean bg_type_locked = terminal_profile_property_locked (profile, TERMINAL_PROFILE_BACKGROUND_TYPE);
-		SET_SENSITIVE ("solid-radiobutton", !bg_type_locked);
-		SET_SENSITIVE ("image-radiobutton", !bg_type_locked);
-		SET_SENSITIVE ("transparent-radiobutton", !bg_type_locked);
-
-		bg_type = terminal_profile_get_property_enum (profile, TERMINAL_PROFILE_BACKGROUND_TYPE);
-		if (bg_type == TERMINAL_BACKGROUND_IMAGE)
-		{
-			SET_SENSITIVE ("background-image-filechooser", !terminal_profile_property_locked (profile, TERMINAL_PROFILE_BACKGROUND_IMAGE_FILE));
-			SET_SENSITIVE ("scroll-background-checkbutton", !terminal_profile_property_locked (profile, TERMINAL_PROFILE_SCROLL_BACKGROUND));
-			SET_SENSITIVE ("darken-background-vbox", !terminal_profile_property_locked (profile, TERMINAL_PROFILE_BACKGROUND_DARKNESS));
-		}
-		else if (bg_type == TERMINAL_BACKGROUND_TRANSPARENT)
-		{
-			SET_SENSITIVE ("background-image-filechooser", FALSE);
-			SET_SENSITIVE ("scroll-background-checkbutton", FALSE);
-			SET_SENSITIVE ("darken-background-vbox", !terminal_profile_property_locked (profile, TERMINAL_PROFILE_BACKGROUND_DARKNESS));
-		}
-		else
-		{
-			SET_SENSITIVE ("background-image-filechooser", FALSE);
-			SET_SENSITIVE ("scroll-background-checkbutton", FALSE);
-			SET_SENSITIVE ("darken-background-vbox", FALSE);
-		}
-	}
-#endif
 
 	if (!prop_name ||
 	        prop_name == I_(TERMINAL_PROFILE_USE_SYSTEM_FONT) ||
@@ -324,10 +309,6 @@ profile_notify_sensitivity_cb (TerminalProfile *profile,
 		SET_SENSITIVE ("login-shell-checkbutton",
 		               !terminal_profile_property_locked (profile, TERMINAL_PROFILE_LOGIN_SHELL));
 
-	if (!prop_name || prop_name == I_(TERMINAL_PROFILE_UPDATE_RECORDS))
-		SET_SENSITIVE ("update-records-checkbutton",
-		               !terminal_profile_property_locked (profile, TERMINAL_PROFILE_UPDATE_RECORDS));
-
 	if (!prop_name || prop_name == I_(TERMINAL_PROFILE_PALETTE))
 	{
 		gboolean palette_locked = terminal_profile_property_locked (profile, TERMINAL_PROFILE_PALETTE);
@@ -379,7 +360,7 @@ profile_colors_notify_scheme_combo_cb (TerminalProfile *profile,
                                        GParamSpec *pspec,
                                        GtkComboBox *combo)
 {
-	const GdkColor *fg, *bg;
+	const GdkRGBA *fg, *bg;
 	guint i;
 
 	fg = terminal_profile_get_property_boxed (profile, TERMINAL_PROFILE_FOREGROUND_COLOR);
@@ -389,8 +370,8 @@ profile_colors_notify_scheme_combo_cb (TerminalProfile *profile,
 	{
 		for (i = 0; i < G_N_ELEMENTS (color_schemes); ++i)
 		{
-			if (gdk_color_equal (fg, &color_schemes[i].foreground) &&
-			        gdk_color_equal (bg, &color_schemes[i].background))
+			if (gdk_rgba_equal (&fg, &color_schemes[i].foreground) &&
+			        gdk_rgba_equal (&bg, &color_schemes[i].background))
 				break;
 		}
 	}
@@ -443,15 +424,15 @@ profile_palette_notify_scheme_combo_cb (TerminalProfile *profile,
 }
 
 static void
-palette_color_notify_cb (GtkColorButton *button,
+palette_color_notify_cb (GtkColorChooser *button,
                          GParamSpec *pspec,
                          TerminalProfile *profile)
 {
 	GtkWidget *editor;
-	GdkColor color;
+	GdkRGBA color;
 	guint i;
 
-	gtk_color_button_get_color (button, &color);
+	gtk_color_chooser_get_rgba (button, &color);
 	i = GPOINTER_TO_UINT (g_object_get_data (G_OBJECT (button), "palette-entry-index"));
 
 	editor = gtk_widget_get_toplevel (GTK_WIDGET (button));
@@ -466,7 +447,7 @@ profile_palette_notify_colorpickers_cb (TerminalProfile *profile,
                                         GtkWidget *editor)
 {
 	GtkWidget *w;
-	GdkColor colors[TERMINAL_PALETTE_SIZE];
+	GdkRGBA colors[TERMINAL_PALETTE_SIZE];
 	guint n_colors, i;
 
 	n_colors = G_N_ELEMENTS (colors);
@@ -476,18 +457,13 @@ profile_palette_notify_colorpickers_cb (TerminalProfile *profile,
 	for (i = 0; i < n_colors; i++)
 	{
 		char name[32];
-		GdkColor old_color;
 
 		g_snprintf (name, sizeof (name), "palette-colorpicker-%d", i + 1);
 		w = profile_editor_get_widget (editor, name);
 
-		gtk_color_button_get_color (GTK_COLOR_BUTTON (w), &old_color);
-		if (!gdk_color_equal (&old_color, &colors[i]))
-		{
-			g_signal_handlers_block_by_func (w, G_CALLBACK (palette_color_notify_cb), profile);
-			gtk_color_button_set_color (GTK_COLOR_BUTTON (w), &colors[i]);
-			g_signal_handlers_unblock_by_func (w, G_CALLBACK (palette_color_notify_cb), profile);
-		}
+		g_signal_handlers_block_by_func (w, G_CALLBACK (palette_color_notify_cb), profile);
+		gtk_color_chooser_set_rgba (GTK_COLOR_CHOOSER (w), &colors[i]);
+		g_signal_handlers_unblock_by_func (w, G_CALLBACK (palette_color_notify_cb), profile);
 	}
 }
 
@@ -544,10 +520,8 @@ reset_compat_defaults_cb (GtkWidget       *button,
  */
 
 static void
-init_color_scheme_menu (GtkWidget *combo_box)
+init_color_scheme_menu (GtkWidget *widget)
 {
-	#if GTK_CHECK_VERSION(3, 0, 0)
-
 	GtkCellRenderer *renderer;
 	GtkTreeIter iter;
 	GtkListStore *store;
@@ -562,26 +536,12 @@ init_color_scheme_menu (GtkWidget *combo_box)
 	                                  0, _("Custom"),
 	                                  -1);
 
-	gtk_combo_box_set_model (GTK_COMBO_BOX (combo_box), GTK_TREE_MODEL (store));
+	gtk_combo_box_set_model (GTK_COMBO_BOX (widget), GTK_TREE_MODEL (store));
 	g_object_unref (store);
 
 	renderer = gtk_cell_renderer_text_new ();
-/*FIXME, avoid double loading of color schemes names from UI file */
-/*	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo_box), renderer, TRUE);
-	gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo_box), renderer, "text", 0, NULL);*/
-
-	#else
-
-	int i;
-
-	i = G_N_ELEMENTS (color_schemes);
-	while (i > 0)
-	{
-		gtk_combo_box_prepend_text (GTK_COMBO_BOX (combo_box),
-		                            _(color_schemes[--i].name));
-	}
-
-	#endif
+	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (widget), renderer, TRUE);
+	gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (widget), renderer, "text", 0, NULL);
 }
 
 static char*
@@ -700,7 +660,6 @@ terminal_profile_edit (TerminalProfile *profile,
                        GtkWindow       *transient_parent,
                        const char      *widget_name)
 {
-	char *path;
 	GtkBuilder *builder;
 	GError *error = NULL;
 	GtkWidget *editor, *w;
@@ -717,17 +676,9 @@ terminal_profile_edit (TerminalProfile *profile,
 		return;
 	}
 
-	path = g_build_filename (TERM_PKGDATADIR, "profile-preferences.ui", NULL);
 	builder = gtk_builder_new ();
-	if (!gtk_builder_add_from_file (builder, path, &error))
-	{
-		g_warning ("Failed to load %s: %s\n", path, error->message);
-		g_error_free (error);
-		g_free (path);
-		g_object_unref (builder);
-		return;
-	}
-	g_free (path);
+	gtk_builder_add_from_resource (builder, TERMINAL_RESOURCES_PATH_PREFIX G_DIR_SEPARATOR_S "ui/profile-preferences.ui", &error);
+	g_assert_no_error (error);
 
 	editor = (GtkWidget *) gtk_builder_get_object  (builder, "profile-editor-dialog");
 	g_object_set_data_full (G_OBJECT (editor), "builder",
@@ -775,7 +726,7 @@ terminal_profile_edit (TerminalProfile *profile,
 		gtk_widget_set_tooltip_text (w, text);
 		g_free (text);
 
-		g_signal_connect (w, "notify::color",
+		g_signal_connect (w, "notify::rgba",
 		                  G_CALLBACK (palette_color_notify_cb),
 		                  profile);
 	}
@@ -860,7 +811,6 @@ terminal_profile_edit (TerminalProfile *profile,
 	CONNECT ("title-entry", TERMINAL_PROFILE_TITLE);
 	CONNECT ("title-mode-combobox", TERMINAL_PROFILE_TITLE_MODE);
 	CONNECT ("transparent-radiobutton", TERMINAL_PROFILE_BACKGROUND_TYPE);
-	CONNECT ("update-records-checkbutton", TERMINAL_PROFILE_UPDATE_RECORDS);
 	CONNECT ("use-custom-command-checkbutton", TERMINAL_PROFILE_USE_CUSTOM_COMMAND);
 	CONNECT ("use-custom-default-size-checkbutton", TERMINAL_PROFILE_USE_CUSTOM_DEFAULT_SIZE);
 	CONNECT ("use-theme-colors-checkbutton", TERMINAL_PROFILE_USE_THEME_COLORS);
