@@ -270,9 +270,7 @@ terminal_app_get_screen_by_display_name (const char *display_name,
 
 	if (display == NULL)
 		return NULL;
-	if (screen_number >= 0)
-		screen = gdk_display_get_screen (display, screen_number);
-	if (screen == NULL)
+	else
 		screen = gdk_display_get_default_screen (display);
 
 	return screen;
@@ -657,6 +655,24 @@ profile_list_delete_confirm_response_cb (GtkWidget *dialog,
 	gtk_widget_destroy (dialog);
 }
 
+static void
+mate_dialog_add_button (GtkDialog   *dialog,
+                        const gchar *button_text,
+                        const gchar *icon_name,
+                        gint         response_id)
+{
+	GtkWidget *button;
+
+	button = gtk_button_new_with_mnemonic (button_text);
+	gtk_button_set_image (GTK_BUTTON (button), gtk_image_new_from_icon_name (icon_name, GTK_ICON_SIZE_BUTTON));
+
+	gtk_button_set_use_underline (GTK_BUTTON (button), TRUE);
+	gtk_style_context_add_class (gtk_widget_get_style_context (button), "text-button");
+	gtk_widget_set_can_default (button, TRUE);
+	gtk_widget_show (button);
+	gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, response_id);
+}
+
 static void
 profile_list_delete_button_clicked_cb (GtkWidget *button,
                                        GtkWidget *widget)
@@ -686,12 +702,15 @@ profile_list_delete_button_clicked_cb (GtkWidget *button,
 	                                 _("Delete profile “%s”?"),
 	                                 terminal_profile_get_property_string (selected_profile, TERMINAL_PROFILE_VISIBLE_NAME));
 
-	gtk_dialog_add_buttons (GTK_DIALOG (dialog),
-	                        GTK_STOCK_CANCEL,
-	                        GTK_RESPONSE_REJECT,
-	                        GTK_STOCK_DELETE,
-	                        GTK_RESPONSE_ACCEPT,
-	                        NULL);
+	mate_dialog_add_button (GTK_DIALOG (dialog),
+	                        _("_Cancel"),
+	                        "process-stop",
+	                        GTK_RESPONSE_REJECT);
+
+	mate_dialog_add_button (GTK_DIALOG (dialog),
+	                        _("_Delete"),
+	                        "edit-delete",
+	                        GTK_RESPONSE_ACCEPT);
 
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog),
 	                                 GTK_RESPONSE_ACCEPT);
@@ -1210,7 +1229,7 @@ terminal_app_new_profile (TerminalApp     *app,
 	{
 		GtkWidget *create_button, *grid, *name_label, *name_entry, *base_label, *combo;
 
-		if (!terminal_util_load_builder_file ("profile-new-dialog.ui",
+		if (!terminal_util_load_builder_resource (TERMINAL_RESOURCES_PATH_PREFIX G_DIR_SEPARATOR_S "ui/profile-new-dialog.ui",
 		                                      "new-profile-dialog", &app->new_profile_dialog,
 		                                      "new-profile-create-button", &create_button,
 		                                      "new-profile-grid", &grid,
@@ -1313,7 +1332,7 @@ terminal_app_manage_profiles (TerminalApp     *app,
 		return;
 	}
 
-	if (!terminal_util_load_builder_file ("profile-manager.ui",
+	if (!terminal_util_load_builder_resource (TERMINAL_RESOURCES_PATH_PREFIX G_DIR_SEPARATOR_S "ui/profile-manager.ui",
 	                                      "profile-manager", &dialog,
 	                                      "profiles-treeview-container", &tree_view_container,
 	                                      "new-profile-button", &new_button,
