@@ -343,6 +343,9 @@ terminal_screen_init (TerminalScreen *screen)
 	priv = screen->priv = G_TYPE_INSTANCE_GET_PRIVATE (screen, TERMINAL_TYPE_SCREEN, TerminalScreenPrivate);
 
 	vte_terminal_set_mouse_autohide (VTE_TERMINAL (screen), TRUE);
+#if VTE_CHECK_VERSION (0, 52, 0)
+	vte_terminal_set_bold_is_bright (VTE_TERMINAL (screen), TRUE);
+#endif
 
 	priv->child_pid = -1;
 
@@ -1394,7 +1397,7 @@ get_child_environment (TerminalScreen *screen,
 	GHashTableIter iter;
 	GPtrArray *retval;
 	guint i;
-	const char * const *list_schemas;
+	gchar **list_schemas = NULL;
 	gboolean schema_exists;
 
 	window = gtk_widget_get_toplevel (term);
@@ -1428,13 +1431,14 @@ get_child_environment (TerminalScreen *screen,
 	g_hash_table_remove (env_table, "LINES");
 	g_hash_table_remove (env_table, "MATE_DESKTOP_ICON");
 
-	g_hash_table_replace (env_table, g_strdup ("TERM"), g_strdup ("xterm")); /* FIXME configurable later? */
+	g_hash_table_replace (env_table, g_strdup ("TERM"), g_strdup ("xterm-256color")); /* FIXME configurable later? */
 
 	/* FIXME: moving the tab between windows, or the window between displays will make the next two invalid... */
 	g_hash_table_replace (env_table, g_strdup ("WINDOWID"), g_strdup_printf ("%ld", GDK_WINDOW_XID (gtk_widget_get_window (window))));
 	g_hash_table_replace (env_table, g_strdup ("DISPLAY"), g_strdup (gdk_display_get_name (display)));
 
-	list_schemas = g_settings_list_schemas();
+	g_settings_schema_source_list_schemas (g_settings_schema_source_get_default (), TRUE, &list_schemas, NULL);
+
 	schema_exists = FALSE;
 	for (i = 0; list_schemas[i] != NULL; i++) {
 		if (g_strcmp0 (list_schemas[i], CONF_PROXY_SCHEMA) == 0)
@@ -1443,6 +1447,9 @@ get_child_environment (TerminalScreen *screen,
 			break;
 		}
 	}
+
+	g_strfreev (list_schemas);
+
 	if (schema_exists == TRUE) {
 		terminal_util_add_proxy_env (env_table);
 	}
@@ -1542,7 +1549,6 @@ terminal_screen_launch_child_cb (TerminalScreen *screen)
 {
 	TerminalScreenPrivate *priv = screen->priv;
 	VteTerminal *terminal = VTE_TERMINAL (screen);
-	TerminalProfile *profile;
 	char **env, **argv;
 	char *shell = NULL;
 	GError *err = NULL;
@@ -1556,8 +1562,6 @@ terminal_screen_launch_child_cb (TerminalScreen *screen)
 	                       "[screen %p] now launching the child process\n",
 	                       screen);
 
-	profile = priv->profile;
-
 	env = get_child_environment (screen, &shell);
 
 	if (priv->initial_working_directory)
@@ -1565,11 +1569,6 @@ terminal_screen_launch_child_cb (TerminalScreen *screen)
 	else
 		working_dir = g_get_home_dir ();
 
-	if (!terminal_profile_get_property_boolean (profile, TERMINAL_PROFILE_LOGIN_SHELL))
-		pty_flags |= VTE_PTY_NO_LASTLOG;
-	if (!terminal_profile_get_property_boolean (profile, TERMINAL_PROFILE_UPDATE_RECORDS))
-		pty_flags |= VTE_PTY_NO_UTMP | VTE_PTY_NO_WTMP;
-
 	if (!get_child_command (screen, shell, &spawn_flags, &argv, &err))
 	{
 		handle_error_child (screen, err);
